@@ -5,7 +5,7 @@ use Carp;
 use DBI;
 use base qw(DBI::db);
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 =head1 NAME
 
@@ -112,13 +112,13 @@ Specify how the results should be ordered.  This option can take various values:
 
 =item * a straight scalar or arrayref sorts by the given column(s):
 
-    { order_by => 'foo' }         # equivalent to "ORDER BY foo"
-    { order_by => [ qw(foo bar) } # equiv to "ORDER BY foo,bar"
+    { order_by => 'foo' }           # equivalent to "ORDER BY foo"
+    { order_by => [ qw(foo bar) ] } # equiv to "ORDER BY foo,bar"
 
 =item * a hashref of C<order => column name>, e.g.:
 
     { order_by => { desc => 'foo' } } # equiv to ORDER BY foo DESC
-    { order_by => [ { desc => 'foo' }, { asc => 'bar' }
+    { order_by => [ { desc => 'foo' }, { asc => 'bar' } ] }
        # above is equiv to ORDER BY foo ASC, bar DESC
 
 =back
@@ -134,7 +134,7 @@ query anyway, so you needn't add it yourself.
 An example of using options to control the results you get back:
 
     # Get the name & phone number of the 10 highest-paid men:
-    database->query(
+    database->quick_select(
         'employees', 
         { gender => 'male' },
         { order_by => 'salary', limit => 10, columns => [qw(name phone)] }
@@ -218,10 +218,10 @@ sub _quick_query {
         my @cols = (ref $opts->{columns}) 
             ? @{ $opts->{columns} }
             :    $opts->{columns} ;
-        $which_cols = join(',', map { $self->quote_identifier($_) } @cols);
+        $which_cols = join(',', map { $self->_quote_identifier($_) } @cols);
     }
 
-    $table_name = $self->quote_identifier($table_name);
+    $table_name = $self->_quote_identifier($table_name);
     my @bind_params;
 
     my $sql = {
@@ -232,14 +232,14 @@ sub _quick_query {
     }->{$type};
     if ($type eq 'INSERT') {
         $sql .= "("
-            . join(',', map { $self->quote_identifier($_) } keys %$data)
+            . join(',', map { $self->_quote_identifier($_) } keys %$data)
             . ") VALUES ("
             . join(',', map { "?" } values %$data)
             . ")";
         push @bind_params, values %$data;
     }
     if ($type eq 'UPDATE') {
-        $sql .= join ',', map { $self->quote_identifier($_) .'=?' } keys %$data;
+        $sql .= join ',', map { $self->_quote_identifier($_) .'=?' } keys %$data;
         push @bind_params, values %$data;
     }
 
@@ -257,12 +257,12 @@ sub _quick_query {
                     while (my($op,$value) = each %$v ) {
                         my ($cond, $add_bind_param) 
                             = $self->_get_where_sql($op, $not, $value);
-                        push @stmts, $self->quote_identifier($k) . $cond; 
+                        push @stmts, $self->_quote_identifier($k) . $cond; 
                         push @bind_params, $v->{$op} if $add_bind_param;
                     }
                 }
                 else {
-                    my $clause .= $self->quote_identifier($k);
+                    my $clause .= $self->_quote_identifier($k);
                     if ( ! defined $v ) {
                         $clause .= ' IS NULL';
                     }
@@ -287,15 +287,19 @@ sub _quick_query {
 
     # Add an ORDER BY clause, if we want to:
     if (exists $opts->{order_by}) {
-        $sql .= $self->_build_order_by_clause($opts->{order_by});
+        $sql .= ' ' . $self->_build_order_by_clause($opts->{order_by});
     }
 
 
     # Add a LIMIT clause if we want to:
     if (exists $opts->{limit}) {
-        if ($opts->{limit} =~ /^\d+$/) {
+        my $limit = $opts->{limit};
+        $limit =~ s/\s+//g;
+        # Check the limit clause is sane - just a number, or two numbers with a
+        # comma between (if using offset,limit )
+        if ($limit =~ m{ ^ \d+ (?: , \d+)? $ }x) {
             # Checked for sanity above so safe to interpolate
-            $sql .= " LIMIT $opts->{limit}";
+            $sql .= " LIMIT $limit";
         } else {
             die "Invalid LIMIT param $opts->{limit} !";
         }
@@ -391,7 +395,7 @@ sub _build_order_by_clause {
     my @sort_fields;
     for my $field (@$in) {
         if (!ref $field) {
-            push @sort_fields, $self->quote_identifier($field);
+            push @sort_fields, $self->_quote_identifier($field);
         } elsif (ref $field eq 'HASH') {
             my ($order, $name) = %$field;
             $order = uc $order;
@@ -400,13 +404,22 @@ sub _build_order_by_clause {
             }
             # $order has been checked to be 'ASC' or 'DESC' above, so safe to
             # interpolate
-            push @sort_fields, $self->quote_identifier($name) . " $order";
+            push @sort_fields, $self->_quote_identifier($name) . " $order";
         }
     }
 
     return "ORDER BY " . join ', ', @sort_fields;
 }
 
+# A wrapper around DBI's quote_identifier which first splits on ".", so that
+# e.g. database.table gets quoted as `database`.`table`, not `database.table`
+sub _quote_identifier {
+    my ($self, $identifier) = @_;
+
+    return join '.', map { 
+        $self->quote_identifier($_) 
+    } split /\./, $identifier;
+}
 
 =back
 
